@@ -1,6 +1,6 @@
-# Build script using external exif library
+# Build script
 # Version number
-PRUNENAME=gpsprune_18.6
+PRUNENAME=gpsprune_19.1
 # remove compile directory
 rm -rf compile
 # remove dist directory
@@ -8,7 +8,7 @@ rm -rf dist
 # create compile directory
 mkdir compile
 # compile java
-javac -cp /usr/share/java/metadata-extractor.jar -d compile $( find tim -name "*.java" -print )
+javac -d compile $( find tim -name "*.java" -print )
 # add other required resources
 cp -r tim/prune/lang compile/tim/prune/
 cp -r tim/prune/*.txt compile/tim/prune/
